Add FP conditional move instructions, which annoyingly have special properties
that require the asmwriter to be extended (printing implicit uses before the
explicit operands)


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@12574 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/X86/X86InstrInfo.h b/lib/Target/X86/X86InstrInfo.h
index 54e3686..61cc5e1 100644
--- a/lib/Target/X86/X86InstrInfo.h
+++ b/lib/Target/X86/X86InstrInfo.h
@@ -155,13 +155,21 @@
     // argument.  For example: fadd, fsub, fmul, etc...
     TwoArgFP   = 4 << FPTypeShift,
 
+    // CondMovFP - "2 operand" floating point conditional move instructions.
+    CondMovFP  = 5 << FPTypeShift,
+
     // SpecialFP - Special instruction forms.  Dispatch by opcode explicitly.
-    SpecialFP  = 5 << FPTypeShift,
+    SpecialFP  = 6 << FPTypeShift,
 
-    // PrintImplUses - Print out implicit uses in the assembly output.
-    PrintImplUses = 1 << 18,
+    // PrintImplUsesAfter - Print out implicit uses in the assembly output after
+    // the normal operands.
+    PrintImplUsesAfter = 1 << 18,
 
-    OpcodeShift   = 19,
+    // PrintImplUsesBefore - Print out implicit uses in the assembly output before
+    // the normal operands.
+    PrintImplUsesBefore = 1 << 19,
+
+    OpcodeShift   = 20,
     OpcodeMask    = 0xFF << OpcodeShift,
     // Bits 25 -> 31 are unused
   };